@@ -4,7 +4,7 @@ test_that("scdhlm Works with Narozanic and Blair.", {
   
   skip(message = "Auxiliary dataset not included in package.")
   
-  Naro <- read.csv("../../auxilliary/Narozanic and Blair_datasets_long_academic.csv", stringsAsFactors = FALSE)
+  Naro <- read.csv("auxilliary/Narozanic and Blair_datasets_long_academic.csv", stringsAsFactors = FALSE)
   Naro$Session_int <- round(Naro$Session)
   
   Naro_dbl <- lme(Outcome ~ Phase,
